@@ -14,6 +14,9 @@
  * limitations under the License.
  */
 
+use marine_module_interface::interface::InterfaceError;
+use marine_module_interface::it_interface::ITInterfaceError;
+
 use wasmer_it::decoders::wat::Error as WATError;
 use thiserror::Error as ThisError;
 
@@ -37,7 +40,7 @@ pub enum ITParserError {
     #[error(
         "IT section is corrupted: {0}.\
     \nProbably the module was compiled with an old version of marine cli, please try to update and recompile.\
-    \nTo update marine run: cargo install mcli --force"
+    \nTo update marine run: cargo install marine --force"
     )]
     CorruptedITSection(nom::Err<(Vec<u8>, nom::error::ErrorKind)>),
 
@@ -45,6 +48,14 @@ pub enum ITParserError {
     #[error("{0}")]
     IncorrectITFormat(String),
 
+    /// An error occurred while processing module interface.
+    #[error("{0}")]
+    ModuleInterfaceError(#[from] InterfaceError),
+
+    /// An error occurred while processing module IT interface.
+    #[error("{0}")]
+    ModuleITInterfaceError(#[from] ITInterfaceError),
+
     /// An error occurred while parsing file in Wat format.
     #[error("provided file with IT definitions is corrupted: {0}")]
     CorruptedITFile(#[from] WATError),
